#
# spec file for package sfml2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define so_ver -2_4
Name:           sfml2
Version:        2.4.2
Release:        lp150.1.5
Summary:        C++ multimedia library with access to input, sound and display
License:        Zlib
Group:          Development/Libraries/C and C++
Url:            http://www.sfml-dev.org/
Source0:        https://github.com/SFML/SFML/archive/%{version}/SFML-%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM Give up trying to runtime-detect SSE2 on GCC - patch is
# from stb upstream commit 3e175448 and 7a694bdc
Patch0:         dont-try-to-runtime-detect-sse2-on-gcc.diff
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisenc)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)
Requires:       lib%{name}%{so_ver} = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SFML is a multimedia API that provides access to graphics, input,
audio, etc. similar to SDL.

%package -n lib%{name}%{so_ver}
Summary:        Free multimedia C++ API
Group:          System/Libraries

%description -n lib%{name}%{so_ver}
SFML is a multimedia API that provides access to graphics, input,
audio, etc., and may be seen as an object-oriented alternative to
SDL. It can be used as a minimal windowing system to interface with
OpenGL, or as a multimedia library for building games and interactive
programs.

%package devel
Summary:        SFML development files
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{so_ver} = %{version}
Requires:       pkgconfig(gl)
# Conflict with the sfml 1 devel package(same include files)
Conflicts:      sfml-devel

%description devel
SFML is a C++ multimedia API that provides a low and high-level
access to graphics, input, audio, etc., and may be seen as an
object-oriented alternative to SDL. SFML can be used as a minimal
windowing system to interface with OpenGL, or as a multimedia library
for building games or interactive programs.

This subpackage provides the header files needed to build SFML
programs.

%package doc
Summary:        SFML developer documentation
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
SFML is a multimedia API that provides access to graphics, input,
audio, etc. similar to SDL.

This subpackage contains the developer documentation.

%prep
%setup -q -n SFML-%{version}
%patch0 -p1
dos2unix --keepdate license.txt

%build
%cmake -DSFML_BUILD_DOC=TRUE \
       -DSFML_INSTALL_PKGCONFIG_FILES=TRUE \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo
make VERBOSE=1 %{?_smp_mflags}

cd doc/html
%fdupes -s .

%install
%cmake_install

# Remove doc from wrong location
rm -r %{buildroot}%{_datadir}/SFML/doc
rm %{buildroot}%{_datadir}/SFML/*.txt

%post -n lib%{name}%{so_ver} -p /sbin/ldconfig
%postun -n lib%{name}%{so_ver} -p /sbin/ldconfig

%files -n lib%{name}%{so_ver}
%defattr(-,root,root)
%doc readme.txt license.txt changelog.txt
%{_libdir}/libsfml-*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/SFML
%{_libdir}/libsfml-*.so
%{_libdir}/pkgconfig/sfml-*.pc
%{_datadir}/SFML/

%files doc
%defattr(-,root,root)
%doc build/doc/html/* CONTRIBUTING

%changelog
* Thu Jun 29 2017 mlin@suse.com
- Add dont-try-to-runtime-detect-sse2-on-gcc.diff from stb upstream
  * Give up trying to runtime-detect SSE2 on GCC, this fixes build
    failure in 42.3
* Sat Feb 18 2017 jengelh@inai.de
- RPM group fix.
* Wed Feb 15 2017 rpm@fthiessen.de
- Update to version 2.4.2
  * Fixed bug where TransientContextLock would hang
  * Fixed GLX extensions being loaded too late
  * Fix wrong types passed to XChangeProperty
  * Optimized sf::Image::create and made it more exception safe
- Dropped upstream merged fix-glx-extensions.patch
* Wed Jan 25 2017 rpm@fthiessen.de
- Added fix-glx-extensions.patch from upstream to fix missing
  multisampling.
* Sat Nov  5 2016 rpm@fthiessen.de
- Update to version 2.4.1
  * Fixed stack overflow on GlContext creation with multiple threads
  * Fixed fullscreen issue
  * Switched from XCB back to Xlib for windowing
  * Fixed window icon not showing up on some distros
  * Fixed an issue where GNOME flags window unresponsive
  * Fixed leak of XVisualInfo objects during GlxContext creation
  * Fixed possible hang when setting visibility if external
    window sources
* Thu Sep  1 2016 rpm@fthiessen.de
- Update to version 2.4.0
* Sun Jul 17 2016 jengelh@inai.de
- Update summary, trim description
- Enable ogg and vorbis dependencies explicitly
* Tue Sep 29 2015 rpm@fthiessen.de
- Fixed some problems in spec, found by factory-repo-checker:
  * Added baselibs.conf as source
  * Conflict with sfml-devel (sfml version 1.x devel package)
* Thu Sep 24 2015 rpm@fthiessen.de
- Updated to version 2.3.2:
  * Some bug fixes, see:
    http://www.sfml-dev.org/changelog.php#sfml-2.3.2
  * fix-upstream-no-return-in-nonvoid-function.patch got merged
    upstream, removed from spec / disabled.
* Sat Aug  1 2015 rpm@fthiessen.de
- Updated to version 2.3.1
  * Lot of bugfixes, see:
    http://www.sfml-dev.org/changelog.php#sfml-2.3.1
  * Added fix for RPMLint error caused by nonvoid functions
    without default return:
    fix-upstream-no-return-in-nonvoid-function.patch
* Thu Jul 30 2015 rpm@fthiessen.de
- Fixed wrong location in pkgconfig files
- SPEC cleanup
* Sat Feb 21 2015 rpm@fthiessen.de
- update to version 2.2 release
* Tue Sep 30 2014 mailaender@opensuse.org
- update to version 2.1 release
* Mon Sep  3 2012 adam@mizerski.pl
- updated to follow latest changes
- added _service for downloading sources from git
* Sun Aug 14 2011 adam@mizerski.pl
- removed bindings
- removed sfml2-2.0-better_image_smooth.patch
  (it was long before and undocumented)
* Fri Apr 22 2011 adam@mizerski.pl
- added sfml2-2.0-better_image_smooth.patch
* Thu Apr 14 2011 adam@mizerski.pl
- Changed source of sources from svn to git
* Sun Apr  3 2011 adam@mizerski.pl
- update to 2.0 r1816
* Tue Feb 22 2011 adam@mizerski.pl
- update to 2.0 r1800
* Sat Feb  5 2011 adam@mizerski.pl
- new package
